mixedtobit: Estimate tobit regression model parameters with mixed effects

Description Usage Arguments Value

Description

Use multiple outputation (a.k.a. within-cluster resampling) to estimate tobit regression model parameters with mixed effects

Usage

1
2
mixedtobit(formula, data, M, left = -1, id, ch.terms = NULL,
  beta.only = FALSE)

Arguments

formula

a regression formula describing the relationship between the response and the predictors

data

a data.frame containing the response and predictors of interest, as well as cluster IDs

M

the (positive integer) number of outputations (resamples) to perform

left

the location of left censoring

id

a string of the column name in "data" specifying the cluster ID

ch.terms

a vector of column names that should be used as conditional heteroscedasticity covariates

beta.only

a logical variable indicating whether or not to include just beta (this is useful for simulations with memory requirements)

Value

A vector containing the outputated regression coefficient estimates


WannabeSmith/mixedtobit documentation built on June 25, 2019, 2:31 p.m.